//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  reduce_spec.hpp
//! \brief Collection NGeni of generalized integral wrappers CGeni.

#ifndef REDUCE_SPEC_H
#define REDUCE_SPEC_H

#include "registry.hpp"

//!  Function type: Evaluate generalized integral for given vector(s).

typedef RObjNum (*geni_eval)(int, const vector<RObjVecNum>&);


//! A wrapper holding a functional.

class CGeni
{
public:
    string name;
    int narg;
    geni_eval eval;
    string unit_hint;
    string com;
    vector<string> default_args;
    class CCoord coord(class CCoord* co) const;
    class CCoord coord(class CCoord* co1, class CCoord* co2) const;
    CGeni(
        string _txt, int _narg, string _default_arg_str, geni_eval _eval, string _unit_hint,
        string _com = "");
    void register_me() const;
};


//! A singleton class that holds a collection of generalized integrals CGeni.

class SGeniRegistry : public IRegistry<CGeni>, public triv::ISingleton<SGeniRegistry>
{
private:
    virtual string type_name() const { return "generalized integrals"; }
public:
    void display_entries() const;
    static void initialize();
};

#endif // REDUCE_SPEC_H
