//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 1990-, v2(C++) 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  ps_plotter.hpp
//! \brief Declares class CPS_Plotter

#include <map>
#include <string>
#include <vector>

class CAxis;

class CPS_Plotter {
public:
    CPS_Plotter() {}
    CPS_Plotter(CPS_Plotter const&) = delete;
    CPS_Plotter& operator=(CPS_Plotter const&) = delete;
    void start_frame1D(const std::string& caller, const CAxis& _X, const CAxis& _Y);
    void set_labels(const std::string& _xlabel, const std::string& _ylabel);
    void start_frame2D(
        const std::string& caller, const CAxis& _X, const CAxis& _Z, const CAxis& _Y);
    void close_frame2D(
        const CAxis& _X, const CAxis& _Z, const CAxis& _Y,
        const std::string& xlabel, const std::string& zlabel, const std::string& ylabel);
    void add_spec(
        bool as_line, bool new_slice, int style_no,
        const std::vector<double>& xp, const std::vector<double>& yp,
        const std::vector<double>& dyp, const std::vector<std::string>& zentries,
        const std::string& xco, const std::string& yco, const std::string& info);
    void main_line(const std::string& line);
    void doc_line(const std::string& line);
    void copy_header(
        const std::string& fname, const std::string& mode, const bool withDefs,
        std::map<const std::string, std::string>& settings);
    void write_data(const std::string& fname);
private:
    bool p2D;
    const CAxis* X;
    const CAxis* Y;
    const CAxis* Z;
    int ps_snum; //!< Slice number in Postscript file.
    std::string caller;
    std::string xlabel, ylabel;
    std::string ps_accu; //!< Main Postscript cache.
    std::string ps_Doc; //!< Special Postscript cache for doc lines ?.
};
